API
===


.. automodule:: pyramid_sockjs

.. autofunction:: get_session_manager

Session states:

  .. py:data:: STATE_NEW

  .. py:data:: STATE_OPEN

  .. py:data:: STATE_CLOSING

  .. py:data:: STATE_CLOSED

.. autoclass:: Session(id)
     :members:

.. autoclass:: SessionManager
     :members:
